@@ -690,6 +690,11 @@ def test_m3u8_should_propagate_base_uri_to_key():
     assert '/any/key.bin' == obj.keys[0].absolute_uri
 
 
+def test_segment_map_uri_attribute():
+    obj = m3u8.M3U8(playlists.MAP_URI_PLAYLIST)
+    assert obj.segment_map_uri == "fileSequence0.mp4"
+
+
 # custom asserts
 
 def assert_file_content(filename, expected):
